import React from 'react';
import { User, Building2, Folder } from 'lucide-react';

const DeveloperProjectDetails = ({
  developerName,
  developerAddress,
  developerContact,
  developerTotalProject,
  projects = []
}) => {
  return (
    <div className='bg-white rounded-xl shadow-lg py-4'>
      <div className='grid grid-cols-1 md:grid-cols-2 gap-4 px-4 sm:px-6'>
        {/* Developer Details Section */}
        <div className='bg-gray-50 rounded-lg p-4'>
          <p className='font-semibold text-base sm:text-lg mb-3'>
            Developer Details
          </p>
          <hr className='mb-3 border-t-2 border-gray-200' />
          <div className='space-y-3'>
            <div className='flex items-center space-x-3'>
              <Building2 className='text-brand w-5 h-5' />
              <p className='text-xs sm:text-sm text-tertiary'>{developerAddress}</p>
            </div>
            <div className='flex items-center space-x-3'>
              <Folder className='text-brand w-5 h-5' />
              <p className='text-xs sm:text-sm text-tertiary'>
                Total Projects: {developerTotalProject}
              </p>
            </div>
          </div>
        </div>

        {/* Projects Section */}
        <div>
          <p className='font-semibold text-base sm:text-lg mb-3'>
            Project Details
          </p>
          <hr className='mb-3 border-t-2 border-gray-200' />
          <div className="grid grid-cols-1 sm:grid-cols-2 gap-3 sm:gap-4">
            {projects.map((project, index) => (
              <div
                key={index}
                className='
                  bg-[#d9d9d9]
                  px-3 sm:px-4
                  py-3
                  rounded-lg
                  flex
                  flex-col
                  space-y-2
                '
              >
                <div className='flex justify-between items-center'>
                  <p className='font-semibold text-sm sm:text-base'>
                    {project.name}
                  </p>
                  <Building2 className='text-brand w-5 h-5' />
                </div>
                <p className='text-xs sm:text-sm text-tertiary line-clamp-2'>
                  {project.description}
                </p>
                <div className='flex justify-between items-center'>
                  <span className='text-xs text-gray-500'>
                    Project #{index + 1}
                  </span>
                </div>
              </div>
            ))}
          </div>
        </div>
      </div>
    </div>
  );
};

export default DeveloperProjectDetails;